##############################################################################
#
#    Recurrence Rules for Odoo
#    Copyright © 2014, 2018, 2022 XCG Consulting (https://www.xcg-consulting.fr/)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
from odoo import api, fields, models


class RRulePreview(models.TransientModel):
    """Preview of a recurrence rule."""

    _name = "rrules.rrule_preview"
    _description = "Recurrence Rule Preview"

    next0 = fields.Date(string="1", readonly=True)
    next1 = fields.Date(string="2", readonly=True)
    next2 = fields.Date(string="3", readonly=True)
    next3 = fields.Date(string="4", readonly=True)
    next4 = fields.Date(string="5", readonly=True)
    next5 = fields.Date(string="6", readonly=True)
    next6 = fields.Date(string="7", readonly=True)

    @api.model
    def default_get(self, fields_list):
        """framework callback that initializes the data upon display by the client
        side."""

        ret = super().default_get(fields_list)

        rrule_id = self.env.context.get("active_id")
        if not rrule_id:
            return ret
        rrule = self.env["rrules.rrule"].browse(rrule_id).get_rrule(None)

        for i in range(0, 7):
            try:
                ret["next%d" % i] = rrule[i]
            except IndexError:
                break

        return ret
